@@ -1,3 +1,13 @@
+# (C) Copyright 2009-2021 Enthought, Inc., Austin, TX
+# All rights reserved.
+#
+# This software is provided without warranty under the terms of the BSD
+# license included in LICENSE.txt and may be redistributed only under
+# the conditions described in the aforementioned license. The license
+# is also available online at http://www.enthought.com/licenses/BSD.txt
+#
+# Thanks for using Enthought open source!
+
 # ------------------------------------------------------------------------------
 # Copyright (c) 2008, Riverbank Computing Limited
 # All rights reserved.
@@ -13,22 +23,16 @@
 #
 # ------------------------------------------------------------------------------
 
-""" Defines the editor factory for multi-selection enumerations, for all traits toolkit
-backends.
+""" Defines the editor factory for multi-selection enumerations, for all traits
+toolkit backends.
 """
 
-
-
 from traits.api import Range
 
-from ..editor_factory import EditorWithListFactory
-
-# -------------------------------------------------------------------------
-#  'ToolkitEditorFactory' class:
-# -------------------------------------------------------------------------
+from traitsui.editor_factory import EditorWithListFactory
 
 
-class ToolkitEditorFactory(EditorWithListFactory):
+class CheckListEditor(EditorWithListFactory):
     """ Editor factory for checklists.
     """
 
@@ -40,5 +44,5 @@ class ToolkitEditorFactory(EditorWithListFactory):
     cols = Range(1, 20)
 
 
-# Define the CheckListEditor class
-CheckListEditor = ToolkitEditorFactory
+# This alias is deprecated and will be removed in TraitsUI 8.
+ToolkitEditorFactory = CheckListEditor
