@@ -1,24 +1,17 @@
-# -------------------------------------------------------------------------
+# (C) Copyright 2004-2021 Enthought, Inc., Austin, TX
+# All rights reserved.
 #
-#  Copyright (c) 2011, Enthought, Inc.
-#  All rights reserved.
+# This software is provided without warranty under the terms of the BSD
+# license included in LICENSE.txt and may be redistributed only under
+# the conditions described in the aforementioned license. The license
+# is also available online at http://www.enthought.com/licenses/BSD.txt
 #
-#  This software is provided without warranty under the terms of the BSD
-#  license included in LICENSE.txt and may be redistributed only
-#  under the conditions described in the aforementioned license.  The license
-#  is also available online at http://www.enthought.com/licenses/BSD.txt
-#
-#  Thanks for using Enthought open source!
-#
-# -------------------------------------------------------------------------
+# Thanks for using Enthought open source!
 
 """ Editor that displays an interactive Python shell.
 """
 
 
-# FIXME: ToolkitEditorFactory is a proxy class defined here just for backward
-# compatibility. The class has been moved to the
-# traitsui.editors.shell_editor file.
 from traitsui.editors.shell_editor import _ShellEditor as BaseShellEditor
 
 from .editor import Editor
@@ -33,4 +26,4 @@ class _ShellEditor(BaseShellEditor, Editor):
     """
 
     def init(self, parent):
-        super(_ShellEditor, self).init(None)
+        super().init(None)
