@@ -1,6 +1,15 @@
-#------------------------------------------------------------------------------
+# (C) Copyright 2008-2021 Enthought, Inc., Austin, TX
+# All rights reserved.
+#
+# This software is provided without warranty under the terms of the BSD
+# license included in LICENSE.txt and may be redistributed only under
+# the conditions described in the aforementioned license. The license
+# is also available online at http://www.enthought.com/licenses/BSD.txt
+#
+# Thanks for using Enthought open source!
+
+# ------------------------------------------------------------------------------
 # Copyright (c) 2007, Riverbank Computing Limited
-# Copyright (c) 2017, Enthought Inc.
 # All rights reserved.
 #
 # This software is provided without warranty under the terms of the BSD license.
@@ -8,14 +17,13 @@
 # described in the PyQt GPL exception also apply
 #
 # Author: Riverbank Computing Limited
-#------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 
 """Defines the base class for the PyQt-based Traits UI modal and non-modal
    dialogs.
 """
 
 
-from __future__ import absolute_import
 from pyface.qt import QtCore, QtGui
 
 from traits.api import HasPrivateTraits, Instance
@@ -30,25 +38,18 @@ from .helper import restore_window, save_window
 class ButtonEditor(Editor):
     """ Editor for buttons.
     """
-    #-------------------------------------------------------------------------
+
+    # -------------------------------------------------------------------------
     #  Trait definitions:
-    #-------------------------------------------------------------------------
+    # -------------------------------------------------------------------------
 
-    # Action associated with the button
+    #: Action associated with the button
     action = Instance(Action)
 
-    #-------------------------------------------------------------------------
-    #  Initializes the object:
-    #-------------------------------------------------------------------------
-
     def __init__(self, **traits):
         # XXX Why does this need to be an Editor subclass? -- CJW
         HasPrivateTraits.__init__(self, **traits)
 
-    #-------------------------------------------------------------------------
-    #  Handles the associated button being clicked:
-    #-------------------------------------------------------------------------
-
     def perform(self):
         """ Handles the associated button being clicked.
         """
@@ -60,13 +61,22 @@ class BasePanel(_BasePanel):
     """Base class for Traits UI panels.
     """
 
-    def add_button(self, action, bbox, role, method=None, enabled=True,
-                   name=None, default=False):
+    def add_button(
+        self,
+        action,
+        bbox,
+        role,
+        method=None,
+        enabled=True,
+        name=None,
+        default=False,
+    ):
         """ Creates a button.
         """
         ui = self.ui
-        if ((action.defined_when != '') and
-                (not ui.eval_when(action.defined_when))):
+        if (action.defined_when != "") and (
+            not ui.eval_when(action.defined_when)
+        ):
             return None
 
         if name is None:
@@ -76,15 +86,13 @@ class BasePanel(_BasePanel):
         button.setAutoDefault(False)
         button.setDefault(default)
         button.setEnabled(enabled)
-        if (method is None) or (action.enabled_when != '') or (id != ''):
-            editor = ButtonEditor(ui=ui,
-                                  action=action,
-                                  control=button)
-            if id != '':
+        if (method is None) or (action.enabled_when != "") or (id != ""):
+            editor = ButtonEditor(ui=ui, action=action, control=button)
+            if id != "":
                 ui.info.bind(id, editor)
-            if action.visible_when != '':
+            if action.visible_when != "":
                 ui.add_visible(action.visible_when, editor)
-            if action.enabled_when != '':
+            if action.enabled_when != "":
                 ui.add_enabled(action.enabled_when, editor)
             if method is None:
                 method = editor.perform
@@ -92,24 +100,27 @@ class BasePanel(_BasePanel):
         if method is not None:
             button.clicked.connect(method)
 
-        if action.tooltip != '':
+        if action.tooltip != "":
             button.setToolTip(action.tooltip)
 
         return button
 
-    def _on_undoable(self, state):
+    def _on_undoable(self, event):
         """Handles a change to the "undoable" state of the undo history
         """
+        state = event.new
         self.undo.setEnabled(state)
 
-    def _on_redoable(self, state):
+    def _on_redoable(self, event):
         """Handles a change to the "redoable" state of the undo history.
         """
+        state = event.new
         self.redo.setEnabled(state)
 
-    def _on_revertable(self, state):
+    def _on_revertable(self, event):
         """ Handles a change to the "revert" state.
         """
+        state = event.new
         self.revert.setEnabled(state)
 
 
@@ -129,18 +140,25 @@ class _StickyDialog(QtGui.QDialog):
         self.setLayout(layout)
 
         # Set the dialog's window flags and properties.
-        if ui.view.resizable:
-            flags = QtCore.Qt.Window
-        else:
-            flags = QtCore.Qt.Dialog | QtCore.Qt.WindowSystemMenuHint
+        # On some X11 window managers, using the Dialog flag instead of
+        # just the Window flag could cause the subsequent minimize and maximize
+        # button hint to be ignored such that those actions are not
+        # available (but the window can still be resize unless the size
+        # constraint is fixed). On some X11 window managers, having two
+        # _StickyDialog open where one has a Window flag and other has a Dialog
+        # flag results in the latter (Dialog) to be always placed on top of
+        # the former (Window).
+        flags = QtCore.Qt.Window
+        if not ui.view.resizable:
+            flags |= QtCore.Qt.WindowSystemMenuHint
             layout.setSizeConstraint(QtGui.QLayout.SetFixedSize)
-            if ui.view.resizable:
-                flags |= QtCore.Qt.WindowMinimizeButtonHint | QtCore.Qt.WindowMaximizeButtonHint
         try:
             flags |= QtCore.Qt.WindowCloseButtonHint
             if ui.view.resizable:
-                flags |= (QtCore.Qt.WindowMinimizeButtonHint |
-                          QtCore.Qt.WindowMaximizeButtonHint)
+                flags |= (
+                    QtCore.Qt.WindowMinimizeButtonHint
+                    | QtCore.Qt.WindowMaximizeButtonHint
+                )
         except AttributeError:
             # Either PyQt or Qt is too old.
             pass
@@ -167,8 +185,10 @@ class _StickyDialog(QtGui.QDialog):
         """Reimplemented to ignore the Escape key if appropriate, and to ignore
         the Enter key if no default button has been explicitly set."""
 
-        if e.key() in (QtCore.Qt.Key_Enter, QtCore.Qt.Key_Return) and \
-                not self._ui.view.default_button:
+        if (
+            e.key() in (QtCore.Qt.Key_Enter, QtCore.Qt.Key_Return)
+            and not self._ui.view.default_button
+        ):
             return
 
         if e.key() == QtCore.Qt.Key_Escape and not self._ok_to_close():
@@ -222,7 +242,7 @@ class _StickyDialog(QtGui.QDialog):
 class BaseDialog(BasePanel):
     """Base class for Traits UI dialog boxes."""
 
-    # The different dialog styles.
+    #: The different dialog styles.
     NONMODAL, MODAL, POPUP = list(range(3))
 
     def init(self, ui, parent, style):
@@ -313,15 +333,11 @@ class BaseDialog(BasePanel):
 
         self.control.setWindowIcon(icon.create_icon())
 
-    def _on_error(self, errors):
+    def _on_error(self, event):
         """Handles editing errors."""
-
+        errors = event.new
         self.ok.setEnabled(errors == 0)
 
-    #-------------------------------------------------------------------------
-    #  Adds a menu bar to the dialog:
-    #-------------------------------------------------------------------------
-
     def _add_menubar(self):
         """Adds a menu bar to the dialog.
         """
@@ -329,13 +345,10 @@ class BaseDialog(BasePanel):
         if menubar is not None:
             self._last_group = self._last_parent = None
             self.control.layout().setMenuBar(
-                menubar.create_menu_bar(self.control, self))
+                menubar.create_menu_bar(self.control, self)
+            )
             self._last_group = self._last_parent = None
 
-    #-------------------------------------------------------------------------
-    #  Adds a tool bar to the dialog:
-    #-------------------------------------------------------------------------
-
     def _add_toolbar(self):
         """ Adds a toolbar to the dialog.
         """
@@ -347,10 +360,6 @@ class BaseDialog(BasePanel):
             self.control._mw.addToolBar(qt_toolbar)
             self._last_group = self._last_parent = None
 
-    #-------------------------------------------------------------------------
-    #  Adds a status bar to the dialog:
-    #-------------------------------------------------------------------------
-
     def _add_statusbar(self):
         """ Adds a statusbar to the dialog.
         """
@@ -374,14 +383,14 @@ class BaseDialog(BasePanel):
                 control.addWidget(item_control, stretch)
 
                 # Set up event listener for updating the status text
-                col = name.find('.')
-                obj = 'object'
+                col = name.find(".")
+                obj = "object"
                 if col >= 0:
                     obj = name[:col]
-                    name = name[col + 1:]
+                    name = name[col + 1 :]
                 obj = self.ui.context[obj]
                 set_text = self._set_status_text(item_control)
-                obj.on_trait_change(set_text, name, dispatch='ui')
+                obj.observe(set_text, name, dispatch="ui")
                 listeners.append((obj, set_text, name))
 
             self.control._mw.setStatusBar(control)
@@ -390,7 +399,9 @@ class BaseDialog(BasePanel):
     def _set_status_text(self, control):
         """ Helper function for _add_statusbar.
         """
-        def set_status_text(text):
+
+        def set_status_text(event):
+            text = event.new
             control.setText(text)
 
         return set_status_text
