@@ -1,19 +1,12 @@
-# ------------------------------------------------------------------------------
+# (C) Copyright 2004-2021 Enthought, Inc., Austin, TX
+# All rights reserved.
 #
-#  Copyright (c) 2005, Enthought, Inc.
-#  All rights reserved.
+# This software is provided without warranty under the terms of the BSD
+# license included in LICENSE.txt and may be redistributed only under
+# the conditions described in the aforementioned license. The license
+# is also available online at http://www.enthought.com/licenses/BSD.txt
 #
-#  This software is provided without warranty under the terms of the BSD
-#  license included in LICENSE.txt and may be redistributed only
-#  under the conditions described in the aforementioned license.  The license
-#  is also available online at http://www.enthought.com/licenses/BSD.txt
-#
-#  Thanks for using Enthought open source!
-#
-#  Author: David C. Morrill
-#  Date:   10/07/2004
-#
-# ------------------------------------------------------------------------------
+# Thanks for using Enthought open source!
 
 """ Defines the View class used to represent the structural content of a
     Traits-based user interface.
@@ -31,9 +24,9 @@ from traits.api import (
     Float,
     Instance,
     List,
+    PrefixList,
     Str,
     Trait,
-    TraitPrefixList,
 )
 
 from .view_element import ViewElement, ViewSubElement
@@ -61,7 +54,6 @@ from .item import Item
 
 from .include import Include
 
-
 # -------------------------------------------------------------------------
 #  Trait definitions:
 # -------------------------------------------------------------------------
@@ -106,9 +98,8 @@ ATitle = Str(desc="the window title for the view")
 #   pages, which can be accessed by clicking **Next** and **Back** buttons.
 #   Changes to attribute values are applied only when the user clicks the
 #   **Finish** button on the last page.
-AKind = Trait(
-    "live",
-    TraitPrefixList(
+AKind = PrefixList(
+    (
         "panel",
         "subpanel",
         "modal",
@@ -120,6 +111,7 @@ AKind = Trait(
         "info",
         "wizard",
     ),
+    default_value='live',
     desc="the kind of view window to create",
     cols=4,
 )
