@@ -1,29 +1,27 @@
-#------------------------------------------------------------------------------
+# (C) Copyright 2004-2021 Enthought, Inc., Austin, TX
+# All rights reserved.
 #
-#  Copyright (c) 2005, Enthought, Inc.
-#  All rights reserved.
+# This software is provided without warranty under the terms of the BSD
+# license included in LICENSE.txt and may be redistributed only under
+# the conditions described in the aforementioned license. The license
+# is also available online at http://www.enthought.com/licenses/BSD.txt
 #
-#  This software is provided without warranty under the terms of the BSD
-#  license included in enthought/LICENSE.txt and may be redistributed only
-#  under the conditions described in the aforementioned license.  The license
-#  is also available online at http://www.enthought.com/licenses/BSD.txt
-#
-#  Thanks for using Enthought open source!
-#------------------------------------------------------------------------------
+# Thanks for using Enthought open source!
 
 """ Defines the various color editors for the Wx user interface toolkit.
 """
 
-#------------------------------------------------------------------------------
-#  Imports:
-#------------------------------------------------------------------------------
+
+
+import sys
 
 import wx
-import wx.combo
+import wx.adv
 
 from traits.api import List, TraitError
-from traitsui.editors.color_editor \
-    import ToolkitEditorFactory as BaseToolkitEditorFactory
+from traitsui.editors.color_editor import (
+    ToolkitEditorFactory as BaseToolkitEditorFactory,
+)
 
 from .editor_factory import SimpleEditor as BaseSimpleEditor
 from .editor_factory import ReadonlyEditor as BaseReadonlyEditor
@@ -32,16 +30,14 @@ from .editor_factory import TextEditor as BaseTextEditor
 from .color_trait import w3c_color_database
 from .helper import TraitsUIPanel
 
-# Version dependent imports (ColourPtr not defined in wxPython 2.5):
-try:
-    ColorTypes = (wx.Colour, wx.ColourPtr)
-except:
-    ColorTypes = wx.Colour
+
+ColorTypes = (wx.Colour,)
 
 
-#---------------------------------------------------------------------------
+# ---------------------------------------------------------------------------
 #  The Wx ToolkitEditorFactory class.
-#---------------------------------------------------------------------------
+# ---------------------------------------------------------------------------
+
 
 class ToolkitEditorFactory(BaseToolkitEditorFactory):
     """ Wx editor factory for color editors.
@@ -52,7 +48,7 @@ class ToolkitEditorFactory(BaseToolkitEditorFactory):
         """
         if color is None:
             if self.mapped:
-                color = getattr(editor.object, editor.name + '_')
+                color = getattr(editor.object, editor.name + "_")
             else:
                 color = getattr(editor.object, editor.name)
 
@@ -60,19 +56,11 @@ class ToolkitEditorFactory(BaseToolkitEditorFactory):
             color = wx.Colour(*[int(round(c * 255.0)) for c in color])
         return color
 
-    #--------------------------------------------------------------------------
-    #  Gets the application equivalent of a wxPython value:
-    #--------------------------------------------------------------------------
-
     def from_wx_color(self, color):
         """ Gets the application equivalent of a wxPython value.
         """
         return color.Red(), color.Green(), color.Blue()
 
-    #--------------------------------------------------------------------------
-    #  Returns the text representation of a specified color value:
-    #--------------------------------------------------------------------------
-
     def str_color(self, color):
         """ Returns the text representation of a specified color value.
         """
@@ -80,19 +68,27 @@ class ToolkitEditorFactory(BaseToolkitEditorFactory):
             alpha = color.Alpha()
             if alpha == 255:
                 return "rgb(%d,%d,%d)" % (
-                    color.Red(), color.Green(), color.Blue())
+                    color.Red(),
+                    color.Green(),
+                    color.Blue(),
+                )
 
-            return "rgb(%d,%d,%d,%d)" % (
-                color.Red(), color.Green(), color.Blue(), alpha)
+            return "rgba(%d,%d,%d,%d)" % (
+                color.Red(),
+                color.Green(),
+                color.Blue(),
+                alpha,
+            )
 
         return str(color)
 
 
-#------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 #  'ColorComboBox' class:
-#------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 
-class ColorComboBox(wx.combo.OwnerDrawnComboBox):
+
+class ColorComboBox(wx.adv.OwnerDrawnComboBox):
 
     def OnDrawItem(self, dc, rect, item, flags):
 
@@ -102,26 +98,31 @@ class ColorComboBox(wx.combo.OwnerDrawnComboBox):
 
         color_name = self.GetString(item)
 
-        dc.DrawText(color_name, r.x + 3,
-                    r.y + (r.height - dc.GetCharHeight()) / 2)
+        dc.DrawText(
+            color_name, r.x + 3, r.y + (r.height - dc.GetCharHeight()) // 2
+        )
 
-        if color_name == 'custom':
-            swatch = wx.Rect(r.x + r.width - swatch_size, r.y + 1,
-                             swatch_size, swatch_size)
-            dc.GradientFillLinear(swatch, wx.Colour(255, 255, 0),
-                                  wx.Colour(0, 0, 255))
+        if color_name == "custom":
+            swatch = wx.Rect(
+                r.x + r.width - swatch_size, r.y + 1, swatch_size, swatch_size
+            )
+            dc.GradientFillLinear(
+                swatch, wx.Colour(255, 255, 0), wx.Colour(0, 0, 255)
+            )
         else:
             color = w3c_color_database.Find(color_name)
 
             brush = wx.Brush(color)
             dc.SetBrush(brush)
-            dc.DrawRectangle(r.x + r.width - swatch_size, r.y + 1,
-                             swatch_size, swatch_size)
+            dc.DrawRectangle(
+                r.x + r.width - swatch_size, r.y + 1, swatch_size, swatch_size
+            )
 
 
-#------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 #  'SimpleColorEditor' class:
-#------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
+
 
 class SimpleColorEditor(BaseSimpleEditor):
     """ Simple style of color editor, which displays a text field whose
@@ -129,18 +130,34 @@ class SimpleColorEditor(BaseSimpleEditor):
     a dialog box for selecting a new color value.
     """
 
-    #--------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     #  Invokes the pop-up editor for an object trait:
-    #--------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
 
     choices = List()
 
     def _choices_default(self):
         """ by default, uses the W3C 16 color names.
         """
-        return ['aqua', 'black', 'blue', 'fuchsia', 'gray', 'green',
-                'lime', 'maroon', 'navy', 'olive', 'purple', 'red',
-                'silver', 'teal', 'white', 'yellow', 'custom']
+        return [
+            "aqua",
+            "black",
+            "blue",
+            "fuchsia",
+            "gray",
+            "green",
+            "lime",
+            "maroon",
+            "navy",
+            "olive",
+            "purple",
+            "red",
+            "silver",
+            "teal",
+            "white",
+            "yellow",
+            "custom",
+        ]
 
     def init(self, parent):
         """
@@ -149,16 +166,22 @@ class SimpleColorEditor(BaseSimpleEditor):
         current_color = self.factory.to_wx_color(self)
         current_color_name = current_color.GetAsString()
 
-        self.control = ColorComboBox(parent, -
-                                     1, current_color_name, wx.Point(0, 0), wx.Size(40, -
-                                                                                    1), self.choices, style=wx.wx.CB_READONLY)
+        self.control = ColorComboBox(
+            parent,
+            -1,
+            current_color_name,
+            wx.Point(0, 0),
+            wx.Size(40, -1),
+            self.choices,
+            style=wx.CB_READONLY,
+        )
 
         self.control.Bind(wx.EVT_COMBOBOX, self.color_selected)
-        return
 
-    #--------------------------------------------------------------------------
-    #  Updates the editor when the object trait changes external to the editor:
-    #--------------------------------------------------------------------------
+    def dispose(self):
+        if self.control is not None:
+            self.control.Unbind(wx.EVT_COMBOBOX, handler=self.color_selected)
+        super().dispose()
 
     def update_editor(self):
         """ Updates the editor when the object trait changes externally to the
@@ -174,7 +197,7 @@ class SimpleColorEditor(BaseSimpleEditor):
 
         color_name = self.choices[event.Selection]
 
-        if color_name == 'custom':
+        if color_name == "custom":
             color_dialog = wx.ColourDialog(self.control)
             result = color_dialog.ShowModal()
             if result == wx.ID_CANCEL:
@@ -195,15 +218,16 @@ class SimpleColorEditor(BaseSimpleEditor):
         """ Returns the text representation of a specified color value.
         """
         color_name = w3c_color_database.FindName(color)
-        if color_name != '':
+        if color_name != "":
             return color_name
 
         return color.GetAsString()
 
 
-#------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 #  'CustomColorEditor' class:
-#------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
+
 
 class CustomColorEditor(BaseSimpleEditor):
     """ Simple style of color editor, which displays a text field whose
@@ -211,10 +235,6 @@ class CustomColorEditor(BaseSimpleEditor):
     a dialog box for selecting a new color value.
     """
 
-    #--------------------------------------------------------------------------
-    #  Invokes the pop-up editor for an object trait:
-    #--------------------------------------------------------------------------
-
     def init(self, parent):
         """
         Finishes initializing the editor by creating the underlying widget.
@@ -223,15 +243,15 @@ class CustomColorEditor(BaseSimpleEditor):
         sizer = wx.BoxSizer(wx.HORIZONTAL)
 
         # 'text_control' is the text display of the color.
-        text_control = wx.TextCtrl(parent, -1, self.str_value,
-                                   style=wx.TE_PROCESS_ENTER)
-        wx.EVT_KILL_FOCUS(text_control, self.update_object)
-        wx.EVT_TEXT_ENTER(parent, text_control.GetId(), self.update_object)
+        text_control = wx.TextCtrl(
+            parent, -1, self.str_value, style=wx.TE_PROCESS_ENTER
+        )
+        text_control.Bind(wx.EVT_KILL_FOCUS, self.update_object)
+        parent.Bind(wx.EVT_TEXT_ENTER, self.update_object, id=text_control.GetId())
 
         # 'button_control' shows the 'Edit' button.
-        button_control = wx.Button(parent, label='Edit', style=wx.BU_EXACTFIT)
-        wx.EVT_BUTTON(button_control, button_control.GetId(),
-                      self.open_color_dialog)
+        button_control = wx.Button(parent, label="Edit", style=wx.BU_EXACTFIT)
+        button_control.Bind(wx.EVT_BUTTON, self.open_color_dialog, id=button_control.GetId())
 
         sizer.Add(text_control, wx.ALIGN_LEFT)
         sizer.AddSpacer(8)
@@ -267,10 +287,6 @@ class CustomColorEditor(BaseSimpleEditor):
         self.control.SetBackgroundColour(color)
         self._text_control.SetValue(self.string_value(color))
 
-    #--------------------------------------------------------------------------
-    #  Updates the editor when the object trait changes external to the editor:
-    #--------------------------------------------------------------------------
-
     def update_editor(self):
         """ Updates the editor when the object trait changes externally to the
             editor.
@@ -308,71 +324,56 @@ class CustomColorEditor(BaseSimpleEditor):
         """ Returns the text representation of a specified color value.
         """
         color_name = w3c_color_database.FindName(color)
-        if color_name != '':
+        if color_name != "":
             return color_name
 
         return self.factory.str_color(color)
 
 
-#------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 #  'ReadonlyColorEditor' class:
-#------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
+
 
 class ReadonlyColorEditor(BaseReadonlyEditor):
     """ Read-only style of color editor, which displays a read-only text field
     whose background color is the color value.
     """
 
-    #--------------------------------------------------------------------------
-    #  Finishes initializing the editor by creating the underlying toolkit
-    #  widget:
-    #--------------------------------------------------------------------------
-
     def init(self, parent):
         """ Finishes initializing the editor by creating the underlying toolkit
             widget.
         """
         self.control = wx.TextCtrl(parent, style=wx.TE_READONLY)
 
-    #--------------------------------------------------------------------------
-    #  Updates the editor when the object trait changes external to the editor:
-    #--------------------------------------------------------------------------
-
     def update_editor(self):
         """ Updates the editor when the object trait changes externally to the
             editor.
         """
-        #super(ReadonlyColorEditor, self).update_editor()
+        # super().update_editor()
         self.control.SetValue(self.string_value(self.value))
         set_color(self)
 
-    #--------------------------------------------------------------------------
-    #  Returns the text representation of a specified color value:
-    #--------------------------------------------------------------------------
-
     def string_value(self, color):
         """ Returns the text representation of a specified color value.
         """
         color_name = w3c_color_database.FindName(color)
-        if color_name != '':
+        if color_name != "":
             return color_name
 
         return self.factory.str_color(color)
 
 
-#------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 #  'ReadonlyColorEditor' class:
-#------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
+
 
 class TextColorEditor(BaseTextEditor):
     """ Text style of color editor, which displays a text field
     whose background color is the color value.
     """
 
-    #--------------------------------------------------------------------------
-    #  Updates the editor when the object trait changes external to the editor:
-    #--------------------------------------------------------------------------
-
     def update_editor(self):
         """ Updates the editor when the object trait changes externally to the
             editor.
@@ -391,23 +392,20 @@ class TextColorEditor(BaseTextEditor):
         except TraitError:
             pass
 
-    #--------------------------------------------------------------------------
-    #  Returns the text representation of a specified color value:
-    #--------------------------------------------------------------------------
-
     def string_value(self, color):
         """ Returns the text representation of a specified color value.
         """
         color_name = w3c_color_database.FindName(color)
-        if color_name != '':
+        if color_name != "":
             return color_name
 
         return self.factory.str_color(color)
 
 
-#------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 #   Sets the color of the specified editor's color control:
-#------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
+
 
 def set_color(editor):
     """  Sets the color of the specified color control.
