@@ -1,19 +1,12 @@
-# ------------------------------------------------------------------------------
+# (C) Copyright 2004-2021 Enthought, Inc., Austin, TX
+# All rights reserved.
 #
-#  Copyright (c) 2005, Enthought, Inc.
-#  All rights reserved.
+# This software is provided without warranty under the terms of the BSD
+# license included in LICENSE.txt and may be redistributed only under
+# the conditions described in the aforementioned license. The license
+# is also available online at http://www.enthought.com/licenses/BSD.txt
 #
-#  This software is provided without warranty under the terms of the BSD
-#  license included in LICENSE.txt and may be redistributed only
-#  under the conditions described in the aforementioned license.  The license
-#  is also available online at http://www.enthought.com/licenses/BSD.txt
-#
-#  Thanks for using Enthought open source!
-#
-#  Author: David C. Morrill
-#  Date:   07/01/2005
-#
-# ------------------------------------------------------------------------------
+# Thanks for using Enthought open source!
 
 """ Defines the table editor for the wxPython user interface toolkit.
 """
@@ -453,7 +446,7 @@ class TableEditor(Editor, BaseTableEditor):
                 tb_sizer.Add((1, 1), 1, wx.EXPAND)
                 tb_sizer.Add(toolbar.control, 0)
 
-            sizer.Add(tb_sizer, 0, wx.ALIGN_RIGHT | wx.EXPAND)
+            sizer.Add(tb_sizer, 0, wx.EXPAND)
 
     def dispose(self):
         """ Disposes of the contents of an editor.
@@ -480,7 +473,7 @@ class TableEditor(Editor, BaseTableEditor):
         # Break any links needed to allow garbage collection:
         self.grid = self.model = self.toolbar = None
 
-        super(TableEditor, self).dispose()
+        super().dispose()
 
     def update_editor(self):
         """ Updates the editor when the object trait changes externally to the
@@ -1513,7 +1506,7 @@ class TableEditorToolbar(HasPrivateTraits):
     control = Any()
 
     def __init__(self, parent=None, **traits):
-        super(TableEditorToolbar, self).__init__(**traits)
+        super().__init__(**traits)
         editor = self.editor
         factory = editor.factory
         actions = []
@@ -1554,7 +1547,7 @@ class TableEditorToolbar(HasPrivateTraits):
             self.control.SetSize(wx.Size(23 * len(actions), 16))
 
     # -------------------------------------------------------------------------
-    #  PyFace/Traits menu/toolbar controller interface:
+    #  Pyface/Traits menu/toolbar controller interface:
     # -------------------------------------------------------------------------
 
     def add_to_menu(self, menu_item):
