@@ -1,19 +1,12 @@
-# -------------------------------------------------------------------------
+# (C) Copyright 2004-2021 Enthought, Inc., Austin, TX
+# All rights reserved.
 #
-#  Copyright (c) 2007, Enthought, Inc.
-#  All rights reserved.
+# This software is provided without warranty under the terms of the BSD
+# license included in LICENSE.txt and may be redistributed only under
+# the conditions described in the aforementioned license. The license
+# is also available online at http://www.enthought.com/licenses/BSD.txt
 #
-#  This software is provided without warranty under the terms of the BSD
-#  license included in LICENSE.txt and may be redistributed only
-#  under the conditions described in the aforementioned license.  The license
-#  is also available online at http://www.enthought.com/licenses/BSD.txt
-#
-#  Thanks for using Enthought open source!
-#
-#  Author: David C. Morrill
-#  Date:   05/20/2007
-#
-# -------------------------------------------------------------------------
+# Thanks for using Enthought open source!
 
 """ A traits UI editor for editing tabular data (arrays, list of tuples, lists
     of objects, etc).
@@ -152,7 +145,7 @@ class wxListCtrl(wx.ListCtrl, TextEditMixin):
         # manage the reference count for the returned object, and it seems to be
         # gc'ed before they finish using it. So we store an object reference to
         # it to prevent it from going away too soon...
-        self._attr = attr = wx.ListItemAttr()
+        self._attr = attr = wx.ItemAttr()
         editor = self._editor
         object, name = editor.object, editor.name
 
@@ -434,7 +427,7 @@ class TabularEditor(Editor):
         self.on_trait_change(self._refresh, "adapter.+update", remove=True)
         self.on_trait_change(self._rebuild_all, "adapter.columns", remove=True)
 
-        super(TabularEditor, self).dispose()
+        super().dispose()
 
     def _update_changed(self, event):
         """ Handles the 'update' event being fired.
@@ -477,9 +470,7 @@ class TabularEditor(Editor):
         """
         self._update_visible = True
 
-        super(TabularEditor, self)._update_editor(
-            object, name, old_value, new_value
-        )
+        super()._update_editor(object, name, old_value, new_value)
 
     def update_editor(self):
         """ Updates the editor when the object trait changes externally to the
@@ -579,13 +570,13 @@ class TabularEditor(Editor):
     def _multi_selected_items_changed(self, event):
         """ Handles the editor's 'multi_selected' trait being modified.
         """
-        values = self.values
+        values = self.value
         try:
             self._multi_selected_rows_items_changed(
                 TraitListEvent(
-                    0,
-                    [values.index(item) for item in event.removed],
-                    [values.index(item) for item in event.added],
+                    index=0,
+                    removed=[values.index(item) for item in event.removed],
+                    added=[values.index(item) for item in event.added],
                 )
             )
         except:
@@ -937,7 +928,7 @@ class TabularEditor(Editor):
         """
         cws = self._cached_widths
         if cws is not None:
-            cws = [(None, cw)[cw >= 0] for cw in cws]
+            cws = [cw if cw is not None and cw >= 0 else None for cw in cws]
 
         return {"cached_widths": cws}
 
