@@ -1,19 +1,12 @@
-# ------------------------------------------------------------------------------
+# (C) Copyright 2004-2021 Enthought, Inc., Austin, TX
+# All rights reserved.
 #
-#  Copyright (c) 2008, Enthought, Inc.
-#  All rights reserved.
+# This software is provided without warranty under the terms of the BSD
+# license included in LICENSE.txt and may be redistributed only under
+# the conditions described in the aforementioned license. The license
+# is also available online at http://www.enthought.com/licenses/BSD.txt
 #
-#  This software is provided without warranty under the terms of the BSD
-#  license included in LICENSE.txt and may be redistributed only
-#  under the conditions described in the aforementioned license.  The license
-#  is also available online at http://www.enthought.com/licenses/BSD.txt
-#
-#  Thanks for using Enthought open source!
-#
-#  Author: David C. Morrill
-#  Date:   08/23/2008
-#
-# ------------------------------------------------------------------------------
+# Thanks for using Enthought open source!
 
 """ A base class for creating custom Traits UI windows.
 """
@@ -51,7 +44,7 @@ class UIWindow(HasPrivateTraits):
     def __init__(self, parent, **traits):
         """ Creates and initializes the window.
         """
-        super(UIWindow, self).__init__(**traits)
+        super().__init__(**traits)
         self.control = wx.Window(
             parent, -1, size=self.size, style=wx.FULL_REPAINT_ON_RESIZE
         )
